@@ -1,9 +1,11 @@
 from ..module import Module
+from ..utils.loading import Loading
+from gitools.utils.utilities import Utilities
 
 
 class UpdateAuthorModule(Module):
     def process(self):
-        self.checkBackup()
+        Module.checkBackup()
         self.selectCommit()
 
         if not self.author_name:
@@ -11,7 +13,8 @@ class UpdateAuthorModule(Module):
         if not self.author_email:
             self.author_email = input("Enter New Author Email: ").strip()
 
-        print()
+        Utilities.clearConsole()
+        loading = Loading("Please wait")
 
         command = (
             """git filter-branch --env-filter 'if [[ $GIT_COMMIT = "COMMIT_HASH" ]]
@@ -29,17 +32,23 @@ class UpdateAuthorModule(Module):
 
         _, err = self.excuteCommand(command)
 
+        loading.stop()
+        Utilities.clearConsole()
+
         if not err:
             print("Commit Author Changed Successfully")
         else:
             print("Commit Author Change Failed, Error:\r\n" + err.decode("utf-8"))
 
+    @staticmethod
     def getFlag():
         return "ua"
 
+    @staticmethod
     def getName():
         return "Update Author"
 
+    @staticmethod
     def getDescription():
         return "Update author information"
 
